Install in editable mode
========================

If you want to work on the package source files, you can install the package in `development mode <https://packaging.python.org/en/latest/guides/distributing-packages-using-setuptools/#working-in-development-mode>`_.
To do this, clone the project from its `GitLab repository <https://gitlab.com/x-rays/numlpa>`_ with:

.. code-block:: bash

   git clone https://gitlab.com/x-rays/numlpa.git

Now execute the following command in the clonned repository:

.. code-block:: bash

   source setup.sh

This will automatically install and activate a virtual environment containing all the necessary dependencies for the development and operation of the package.
